macro_rules! arc_tracked {
($expr:expr) => { ... };
}Expand description
Create an Arc-wrapped pointer and track it Returns the raw pointer
macro_rules! arc_tracked {
($expr:expr) => { ... };
}Create an Arc-wrapped pointer and track it Returns the raw pointer